@@ -1,10 +1,13 @@
-from .dqn import AbstractDQN, DQN
+from .abstract_dqn import AbstractDQN
+from .dqn import DQN
 from .double_dqn import DoubleDQN
 from .averaged_dqn import AveragedDQN
 from .maxmin_dqn import MaxminDQN
 from .dueling_dqn import DuelingDQN
 from .categorical_dqn import CategoricalDQN
+from .noisy_dqn import NoisyDQN
+from .rainbow import Rainbow
 
 
 __all__ = ['AbstractDQN', 'DQN', 'DoubleDQN', 'AveragedDQN', 'MaxminDQN',
-           'DuelingDQN', 'CategoricalDQN']
+           'DuelingDQN', 'CategoricalDQN', 'NoisyDQN', 'Rainbow']
