@@ -18,7 +18,7 @@ class QLambda(TD):
         Constructor.
 
         Args:
-            lambda_coeff ((float, Parameter)): eligibility trace coefficient;
+            lambda_coeff ([float, Parameter]): eligibility trace coefficient;
             trace (str, 'replacing'): type of eligibility trace to use.
 
         """
