@@ -1,4 +1,5 @@
 from .linear import LinearApproximator
 from .torch_approximator import TorchApproximator
+from .cmac import CMAC
 
-__all__ = ['LinearApproximator', 'TorchApproximator']
+__all__ = ['LinearApproximator', 'TorchApproximator', 'CMAC']
